Learn R Programming

noegletalR (version 0.2.1)

noegletalR-package: noegletalR: Tidy Tibbles of Noegletal

Description

Work with data from https://noegletal.dk in a tidy manner. Tidy up previously downloaded data or retrieve new data directly from the comfort of R. You can also browse an up-to-date list of available data, including thorough variable descriptions.

Arguments

Author

Maintainer: Frederik Larsen frlars21@student.aau.dk [copyright holder]

See Also